@@ -545,7 +545,7 @@ class FluxAgent:
         p.mkdir(parents=True, exist_ok=True)
 
         plugins = [
-            str(f).rstrip(".py")
+            f.name.rstrip(".py")
             for f in p.iterdir()
             if not f.is_dir() and not str(f).endswith("runner.py")
         ]
